
# yenviron

Yenviron allows to use [12factor](https://12factor.net/) inspired environment
variables to configure your Django application. It uses YAML files to store
variables so it can be easily integrated with ansible.

This package is based on [django-environ](https://github.com/joke2k/django-environ).
